@@ -12,7 +12,9 @@ using namespace Qt::Literals::StringLiterals;
 static QByteArray readMailFromFile(const QString &mailFile)
 {
     QFile file(QLatin1StringView(MAIL_DATA_DIR) + u'/' + mailFile);
-    file.open(QIODevice::ReadOnly);
+    if (!file.open(QIODevice::ReadOnly)) {
+        Q_ASSERT(false);
+    }
     Q_ASSERT(file.isOpen());
     return file.readAll();
 }
